# coding: utf-8

"""
    Fabric Orchestrator API

    This is Fabric Orchestrator API  # noqa: E501

    OpenAPI spec version: 1.0.1
    Contact: kthare10@unc.edu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

from fabric_cf.orchestrator.swagger_client.api.resources_api import ResourcesApi  # noqa: E501
from fabric_cf.orchestrator.swagger_client.rest import ApiException


class TestResourcesApi(unittest.TestCase):
    """ResourcesApi unit test stubs"""

    def setUp(self):
        self.api = ResourcesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_portalresources_get(self):
        """Test case for portalresources_get

        Retrieve a listing and description of available resources for portal  # noqa: E501
        """
        pass

    def test_resources_get(self):
        """Test case for resources_get

        Retrieve a listing and description of available resources. By default, a cached available resource information is returned. User can force to request the current available resources.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
